@@ -101,7 +101,6 @@ def create_tables(session, gt_column_names, extra_sample_columns):
                         variant_id int, \
                         primary key (sample_name, gts, variant_id))'''))
     
-    
     session.execute(SimpleStatement('''CREATE TABLE IF NOT EXISTS samples_by_variants_gt_type ( \
                     variant_id int, \
                     gt_type int, \
@@ -127,12 +126,20 @@ def create_tables(session, gt_column_names, extra_sample_columns):
                         gene text,
                         PRIMARY KEY (gene, variant_id))'''))
     
+    session.execute(SimpleStatement('''CREATE TABLE if not exists sample_genotype_counts ( \
+                     sample_id int PRIMARY KEY, \
+                     version int,                                   \
+                     num_hom_ref int,                                 \
+                     num_het int,                                     \
+                     num_hom_alt int,                                 \
+                     num_unknown int)'''))
+     
+    
     session.execute(create_variants_table(gt_column_names))
     
     for stmt in create_samples_tables(extra_sample_columns):
         session.execute(stmt)
 
-
 def create_variants_table(gt_column_names):
 
     #TODO: line 230 was hwe decimal(9,7) in sqlite and info was BYTEA
@@ -291,7 +298,7 @@ def create_samples_tables(extra_columns):
     
     return [SimpleStatement(creation_samples), SimpleStatement(creation_samples_by_phenotype), SimpleStatement(creation_samples_by_sex)]
     
-def batch_insert(session, table, columns, contents):
+def batch_insert(session, table, columns, contents, queue_length=120):
     """
     Populate the given table with the given values
     """
@@ -299,13 +306,20 @@ def batch_insert(session, table, columns, contents):
     question_marks = ','.join(list(repeat("?",len(columns))))
     insert_query = session.prepare('INSERT INTO ' + table + ' (' + column_names + ') VALUES (' + question_marks + ')')
     
-    futures = Queue.Queue(maxsize=121)
+    batch_insert_query_prepared(session, insert_query, contents, queue_length)
+        
+def batch_insert_query_prepared(session, prepared_query, contents, queue_length=120):
+    """
+    Populate the given table with the given values
+    """
+    
+    futures = Queue.Queue(maxsize=queue_length+1)
     for i in range(len(contents)):
-        if i >= 120:
+        if i >= queue_length:
             old_future = futures.get_nowait()
             old_future.result()
     
-        future = session.execute_async(insert_query, contents[i])
+        future = session.execute_async(prepared_query, contents[i])
         futures.put_nowait(future)
     
 def insert(session, table, columns, contents):
