@@ -14,7 +14,7 @@ import version
 from ped import load_ped_file
 import gene_table
 import infotag
-from database_cassandra import insert, batch_insert, create_tables
+from database_cassandra import insert, batch_insert, batch_insert_query_prepared, create_tables
 import annotations
 import func_impact
 import severe_impact
@@ -25,26 +25,32 @@ from compression import pack_blob
 from geminicassandra.config import read_gemini_config
 from cassandra.cluster import Cluster
 from blist import blist
-from table_schemes import get_column_names
+from itertools import repeat
 from geminicassandra.ped import get_ped_fields
 import time
 from string import strip
+from random import randint
+from geminicassandra.table_schemes import get_column_names
+from cassandra.query import BatchStatement, BatchType
+import Queue
 
 class GeminiLoader(object):
     """
     Object for creating and populating a geminicassandra
     database and auxillary data files.
     """
-    def __init__(self, args, buffer_size=1000):
+    def __init__(self, args):
         self.args = args
         
         # create a reader for the VCF file
         self.vcf_reader = self._get_vcf_reader()
         
-        self.buffer_size = buffer_size
+        self.buffer_size = args.buffer_size
+        self.queue_length = args.max_queue
         self._get_anno_version()
         self.contact_points = map(strip, args.contact_points.split(','))
         self.keyspace = args.keyspace
+        self.replication_factor = args.replication
         
         self.typed_gt_column_names = []
         self.gt_column_names = []
@@ -54,13 +60,7 @@ class GeminiLoader(object):
             self.gt_column_names, self.typed_gt_column_names = self._get_typed_gt_column_names()
             
         NUM_BUILT_IN = 6
-        self.extra_sample_columns = get_ped_fields(args.ped_file)[NUM_BUILT_IN:]
-        # load sample information
-        
-        
-        '''if not args.skip_gene_tables:
-            self._get_gene_detailed()
-            self._get_gene_summary()'''
+        self.extra_sample_columns = get_ped_fields(args.ped_file)[NUM_BUILT_IN:]        
 
         if self.args.anno_type == "VEP":
             self._effect_fields = self._get_vep_csq(self.vcf_reader)
@@ -76,10 +76,13 @@ class GeminiLoader(object):
                 # load the sample info from the VCF file.
             self._prepare_samples()
                 # initialize genotype counts for each sample
-            self._init_sample_gt_counts()
             self.num_samples = len(self.samples)
         else:
             self.num_samples = 0
+            
+        if not self.args.skip_gene_tables:
+            self._get_gene_detailed()
+            self._get_gene_summary()
 
     def store_vcf_header(self):
         """Store the raw VCF header.
@@ -118,55 +121,89 @@ class GeminiLoader(object):
         else:
             v_id = 1
         return v_id
-
+    
+    def prepare_insert_queries(self):
+        
+        basic_query = 'INSERT INTO %s ( %s ) VALUES ( %s  )'
+        
+        from time import sleep
+        
+        nap = 20*randint(0,6)
+        sleep(nap)
+        
+        start_time = time.time()
+        
+        self.insert_variants_query = self.session.prepare(basic_query % \
+                             ('variants', ','.join(get_column_names('variants') + self.gt_column_names), ','.join(list(repeat("?",len(get_column_names('variants') + self.gt_column_names))))))
+        self.insert_variants_samples_gt_types_query = self.session.prepare(basic_query % \
+                             ('variants_by_samples_gt_types', "variant_id, sample_name, gt_types", ','.join(list(repeat("?",3)))))
+        self.insert_samples_variants_gt_types_query = self.session.prepare(basic_query % \
+                             ('samples_by_variants_gt_type', "variant_id, sample_name, gt_type", ','.join(list(repeat("?",3)))))
+        self.insert_variants_samples_gt_depths_query = self.session.prepare(basic_query % \
+                             ('variants_by_samples_gt_depths', "variant_id, sample_name, gt_depths", ','.join(list(repeat("?",3)))))
+        self.insert_variants_samples_gts_query = self.session.prepare(basic_query % \
+                             ('variants_by_samples_gts', "variant_id, sample_name, gts", ','.join(list(repeat("?",3))))) 
+        self.insert_variant_impacts_query = self.session.prepare(basic_query % \
+                             ('variant_impacts', ','.join(get_column_names('variant_impacts')), ','.join(list(repeat("?", len(get_column_names('variant_impacts')))))))
+        self.insert_variant_stcr_query = self.session.prepare(basic_query % \
+                             ('variants_by_sub_type_call_rate', ','.join(get_column_names('variants_by_sub_type_call_rate')), ','.join(list(repeat("?", 3)))))
+        self.insert_variant_gene_query = self.session.prepare(basic_query % \
+                             ('variants_by_gene', 'variant_id, gene', ','.join(list(repeat("?", 2)))))
+        self.insert_variant_chrom_start_query = self.session.prepare(basic_query % \
+                             ('variants_by_chrom_start', 'variant_id, chrom, start', ','.join(list(repeat("?", 3)))))
+                       
+        end_time = time.time()
+        
+        print("preparing statements took %.2f s." % (end_time - start_time))
+                                                 
     def populate_from_vcf(self):
         """
         """
-        import geminicassandra
         self.v_id = self._get_vid()
         self.var_buffer = blist([])
         self.var_impacts_buffer = blist([])
         self.var_subtypes_buffer = blist([])
         self.var_gene_buffer = blist([])
         self.var_chrom_start_buffer = blist([])
+        self.prepare_insert_queries()
         buffer_count = 0
         self.skipped = 0
         #extra_file, extraheader_file = geminicassandra.get_extra_files(self.args.db)
-        extra_headers = {}
+        #extra_headers = {}
         self.counter = 0
         start_time = time.time()
+        interval_start = time.time()
+        variants_gts_timer = 0
+        log_file = open("loading_logs/%s.csv" % str(os.getpid()), "a")
         #with open(extra_file, "w") as extra_handle:
             # process and load each variant in the VCF file
+        vars_inserted = 0
         for var in self.vcf_reader:
             if self.args.passonly and (var.FILTER is not None and var.FILTER != "."):
                 self.skipped += 1
                 continue
             (variant, variant_impacts, sample_info, extra_fields) = self._prepare_variation(var)
-            #TODO: bekijken
-            '''if extra_fields:
-                extra_handle.write("%s\n" % json.dumps(extra_fields))
-                extra_headers = self._update_extra_headers(extra_headers, extra_fields)'''
             # add the core variant info to the variant buffer
             self.var_buffer.append(variant)
             self.var_subtypes_buffer.append([self.v_id, variant[11], variant[12]])
             if variant[55] != None:
                 self.var_gene_buffer.append([self.v_id, variant[55]])
             self.var_chrom_start_buffer.append([self.v_id, variant[0], variant[1]])
-                
+        
             var_sample_gt_types_buffer = blist([])
             var_sample_gt_depths_buffer = blist([])
             var_sample_gt_buffer = blist([])
                 
             for sample in sample_info:
-                    #TODO: check if gt_type is None. Compare if faster to check client side i.s.o. Cassandra - side
-                var_sample_gt_depths_buffer.append([self.v_id, sample[0], sample[2]])
-                var_sample_gt_types_buffer.append([self.v_id, sample[0], sample[1]])
-                var_sample_gt_buffer.append([self.v_id, sample[0], sample[3]])
-                                    
-            batch_insert(self.session, 'variants_by_samples_gt_types', ["variant_id", "sample_name", "gt_types"], var_sample_gt_types_buffer)
-            batch_insert(self.session, 'samples_by_variants_gt_type', ["variant_id", "sample_name", "gt_type"], var_sample_gt_types_buffer)
-            batch_insert(self.session, 'variants_by_samples_gt_depths', ["variant_id", "sample_name", "gt_depths"], var_sample_gt_depths_buffer)
-            batch_insert(self.session, 'variants_by_samples_gts', ["variant_id", "sample_name", "gts"], var_sample_gt_buffer)
+                if sample[1] != None:
+                    var_sample_gt_depths_buffer.append([self.v_id, sample[0], sample[2]])
+                    var_sample_gt_types_buffer.append([self.v_id, sample[0], sample[1]])
+                    var_sample_gt_buffer.append([self.v_id, sample[0], sample[3]])        
+                             
+            stime = time.time()                       
+            self.prepared_batch_insert(self.session, var_sample_gt_types_buffer, var_sample_gt_depths_buffer, var_sample_gt_buffer)
+            variants_gts_timer += (time.time() - stime)
+            
                 # add each of the impact for this variant (1 per gene/transcript)
             for var_impact in variant_impacts:
                 self.var_impacts_buffer.append(var_impact)
@@ -174,13 +211,13 @@ class GeminiLoader(object):
             buffer_count += 1
                 # buffer full - start to insert into DB
             if buffer_count >= self.buffer_size:
-                batch_insert(self.session, 'variants', get_column_names('variants') + self.gt_column_names, self.var_buffer)
-                batch_insert(self.session, 'variant_impacts', get_column_names('variant_impacts'),
-                                                  self.var_impacts_buffer)
-                batch_insert(self.session, 'variants_by_sub_type_call_rate',\
-                                                 get_column_names('variants_by_sub_type_call_rate'), self.var_subtypes_buffer)
-                batch_insert(self.session, 'variants_by_gene', ['variant_id', 'gene'], self.var_gene_buffer)
-                batch_insert(self.session, 'variants_by_chrom_start', ['variant_id', 'chrom', 'start'], self.var_chrom_start_buffer)
+                startt = time.time()
+                batch_insert_query_prepared(self.session, self.insert_variants_query, self.var_buffer,self.queue_length)
+                batch_insert_query_prepared(self.session, self.insert_variant_impacts_query, self.var_impacts_buffer,self.queue_length)
+                batch_insert_query_prepared(self.session, self.insert_variant_stcr_query, self.var_subtypes_buffer,self.queue_length)
+                batch_insert_query_prepared(self.session, self.insert_variant_gene_query, self.var_gene_buffer,self.queue_length)
+                batch_insert_query_prepared(self.session, self.insert_variant_chrom_start_query, self.var_chrom_start_buffer,self.queue_length)
+                endt = time.time()
                     # binary.genotypes.append(var_buffer)
                     # reset for the next batch
                 self.var_buffer = blist([])
@@ -188,7 +225,14 @@ class GeminiLoader(object):
                 self.var_impacts_buffer = blist([])
                 self.var_gene_buffer = blist([])
                 self.var_chrom_start_buffer = blist([])
+                vars_inserted += self.buffer_size   
+                if(self.args.offset == '1'):                   
+                    print "%s vars done; last %s took %.2f s; var tables %.2f s; var_gt_tables %.2f s" % (vars_inserted, self.buffer_size, endt - interval_start, endt - startt, variants_gts_timer) 
+                log_file.write("%s;%.2f;%.2f;%.2f\n" % (self.buffer_size, endt - interval_start, endt - startt, variants_gts_timer)) 
+                log_file.flush()       
                 buffer_count = 0
+                interval_start = time.time()
+                variants_gts_timer = 0
             self.v_id += 1
             self.counter += 1
         '''if extra_headers:
@@ -198,14 +242,18 @@ class GeminiLoader(object):
             os.remove(extra_file)'''
         # final load to the database
         self.v_id -= 1
-        batch_insert(self.session, 'variants', get_column_names('variants') + self.gt_column_names, self.var_buffer)
-        batch_insert(self.session, 'variant_impacts', get_column_names('variant_impacts'), self.var_impacts_buffer)
-        batch_insert(self.session, 'variants_by_sub_type_call_rate',\
-                                            get_column_names('variants_by_sub_type_call_rate'), self.var_subtypes_buffer)
-        batch_insert(self.session, 'variants_by_gene', ['variant_id', 'gene'], self.var_gene_buffer)
-        batch_insert(self.session, 'variants_by_chrom_start', ['variant_id', 'chrom', 'start'], self.var_chrom_start_buffer)
+        
+        startt = time.time()
+        batch_insert_query_prepared(self.session, self.insert_variants_query, self.var_buffer,self.queue_length)
+        batch_insert_query_prepared(self.session, self.insert_variant_impacts_query, self.var_impacts_buffer,self.queue_length)
+        batch_insert_query_prepared(self.session, self.insert_variant_stcr_query, self.var_subtypes_buffer,self.queue_length)
+        batch_insert_query_prepared(self.session, self.insert_variant_gene_query, self.var_gene_buffer,self.queue_length)
+        batch_insert_query_prepared(self.session, self.insert_variant_chrom_start_query, self.var_chrom_start_buffer,self.queue_length)
         
         end_time = time.time()
+        vars_inserted += self.buffer_size   
+        log_file.write("%s;%.2f;%.2f;%.2f\n" % (self.buffer_size, end_time - interval_start, end_time - startt, variants_gts_timer))        
+        log_file.close()        
         elapsed_time = end_time - start_time            
         sys.stderr.write("pid " + str(os.getpid()) + ": " +
                          str(self.counter) + " variants processed in %s s.\n" % elapsed_time)
@@ -213,6 +261,25 @@ class GeminiLoader(object):
             sys.stderr.write("pid " + str(os.getpid()) + ": " +
                              str(self.skipped) + " skipped due to having the "
                              "FILTER field set.\n")
+            
+    def prepared_batch_insert(self, session, types_buf, depth_buf, gt_buffer, queue_length=120):
+        """
+        Populate the given table with the given values
+        """
+        
+        futures = Queue.Queue(maxsize=queue_length+1)
+        for i in range(len(types_buf)):
+            if i >= queue_length:
+                old_future = futures.get_nowait()
+                old_future.result()
+            
+            batch = BatchStatement(batch_type=BatchType.UNLOGGED)
+            batch.add(self.insert_samples_variants_gt_types_query, types_buf[i])
+            batch.add(self.insert_variants_samples_gt_types_query, types_buf[i])
+            batch.add(self.insert_variants_samples_gt_depths_query, depth_buf[i])
+            batch.add(self.insert_variants_samples_gts_query, gt_buffer[i])
+            future = session.execute_async(batch)
+            futures.put_nowait(future)
 
     def _update_extra_headers(self, headers, cur_fields):
         """Update header information for extra fields.
@@ -314,8 +381,8 @@ class GeminiLoader(object):
         """
         self.cluster = Cluster(self.contact_points)
         self.session = self.cluster.connect()
-        self.session.execute("""CREATE KEYSPACE IF NOT EXISTS %s
-                                WITH replication = {'class': 'SimpleStrategy', 'replication_factor' : 1}""" % self.keyspace)
+        query = "CREATE KEYSPACE IF NOT EXISTS %s WITH replication = {'class': 'SimpleStrategy', 'replication_factor' : %d}" % (self.keyspace, self.replication_factor)
+        self.session.execute(query)
         self.session.set_keyspace(self.keyspace)
         # create the geminicassandra database tables for the new DB
         create_tables(self.session, self.typed_gt_column_names, self.extra_sample_columns)
@@ -338,13 +405,17 @@ class GeminiLoader(object):
         inbreeding_coeff = None
         hom_ref = het = hom_alt = unknown = None
 
-        # only compute certain metrics if genoypes are available
+        # only compute certain metrics if genotypes are available
         if not self.args.no_genotypes and not self.args.no_load_genotypes:
             hom_ref = var.num_hom_ref
             hom_alt = var.num_hom_alt
             het = var.num_het
             unknown = var.num_unknown
-            call_rate = var.call_rate
+            
+            try:
+                call_rate = var.call_rate
+            except ValueError:  #TODO: catch error instead of bogus value
+                call_rate = -43.0
             aaf = var.aaf
             hwe_p_value, inbreeding_coeff = \
                 popgen.get_hwe_likelihood(hom_ref, het, hom_alt, aaf)
@@ -469,8 +540,6 @@ class GeminiLoader(object):
             vcf_id = var.ID
 
         # build up numpy arrays for the genotype information.
-        # these arrays will be pickled-to-binary, compressed,
-        # and loaded as SqlLite BLOB values (see compression.pack_blob)
         sample_info = blist([])
         if not self.args.no_genotypes and not self.args.no_load_genotypes:
             gt_bases = var.gt_bases  # 'A/G', './.'
@@ -486,11 +555,9 @@ class GeminiLoader(object):
             for entry in var.samples:
                 sample_info.append((entry.sample, entry.gt_type, entry.gt_depth, entry.gt_bases))
 
-            # tally the genotypes
-            #TODO: perhapds uncomment? Don't understand the use just yet.
-            '''
-            self._update_sample_gt_counts(gt_types)
-            '''
+            # tally the genotypes            
+            self._update_sample_gt_counts(np.array(var.gt_types, np.int8))
+            
         else:
             gt_columns= []            
         
@@ -637,8 +704,8 @@ class GeminiLoader(object):
                                  "not in the PED file.\n" % (sample))
             else:
                 # if there is no ped file given, just fill in the name and
-                # sample_id and set the other required fields to None
-                sample_list = [i, '0', sample, '0', '0', '-9', '-9']
+                # sample_id and set random value for sex & phenotype
+                sample_list = [i, '0', sample, '0', '0', str(randint(1,2)), str(randint(1,2))]
                 
             samples_buffer.append(sample_list)
             buffer_counter += 1
@@ -755,18 +822,68 @@ class GeminiLoader(object):
         """
         Update the count of each gt type for each sample
         """
-        self.session.execute("BEGIN TRANSACTION")
+        samples_buffer = blist([])
+        buffer_count = 0
         for idx, gt_counts in enumerate(self.sample_gt_counts):
-            self.session.execute("""insert into sample_genotype_counts values \
-                            (?,?,?,?,?)""",
-                           [idx,
-                            int(gt_counts[HOM_REF]),  # hom_ref
-                            int(gt_counts[HET]),  # het
-                            int(gt_counts[HOM_ALT]),  # hom_alt
-                            int(gt_counts[UNKNOWN])])  # missing
-        self.session.execute("END")
-   
-              
+            if buffer_count < 10000:
+                samples_buffer.append([int(gt_counts[HOM_REF]),  # hom_ref
+                                int(gt_counts[HET]),  # het
+                                int(gt_counts[HOM_ALT]),  # hom_alt
+                                int(gt_counts[UNKNOWN]), #missing
+                                idx])
+                buffer_count += 1
+            else:
+                self.batch_insert_gt_counts(samples_buffer)
+                samples_buffer = blist([])
+                buffer_count = 0
+        self.batch_insert_gt_counts(samples_buffer)   
+            
+    def batch_insert_gt_counts(self, contents):
+        
+        update_query = self.session.prepare('''UPDATE sample_genotype_counts    \
+                                               SET num_hom_ref = ?,\
+                                               num_het = ?,            \
+                                               num_hom_alt = ?,    \
+                                               num_unknown = ?,    \
+                                               version = ?   \
+                                               WHERE sample_id = ? \
+                                               IF version = ?''')
+        
+        create_query = self.session.prepare('''INSERT INTO sample_genotype_counts \
+                                               (num_hom_ref,\
+                                               num_het,            \
+                                               num_hom_alt,    \
+                                               num_unknown,    \
+                                               sample_id, \
+                                               version)    \
+                                               VALUES (?,?,?,?,?,?) IF NOT EXISTS''')
+        
+        get_query = self.session.prepare("SELECT * FROM sample_genotype_counts WHERE sample_id = ?")
+        
+        def get_version(sample_id):
+            res = self.session.execute(get_query, [sample_id])
+            if len(res) > 0:
+                return res[0]
+            else:
+                return []
+        
+        retries = []
+        for entry in contents:
+            vals = get_version(entry[4])
+            versioned_entry = entry
+            if vals == []:
+                versioned_entry.append(0)
+                res = self.session.execute(create_query, versioned_entry)
+            else:
+                updated_contents = [entry[0]+vals.num_hom_ref, entry[1]+vals.num_het, entry[2]+vals.num_hom_alt,\
+                                    entry[3]+vals.num_unknown, vals.version + 1, entry[4],  vals.version]
+                res = self.session.execute(update_query, updated_contents)
+            if not res[0].applied:
+                retries.append(entry)  
+                
+        if len(retries) > 0:
+            self.batch_insert_gt_counts(retries)   
+            
 def concat(l):
         return reduce(lambda x, y: x + y, l, [])
     
@@ -777,7 +894,6 @@ def parse_float(s):
     try:
         return float(s)
     except ValueError:
-        #TODO: sensible value?
         return None
     except TypeError:
         return None
@@ -786,7 +902,6 @@ def parse_int(s):
     try:
         return int(s)
     except ValueError:
-        #TODO: sensible value?
         return -42
     except TypeError:
         return -43
@@ -806,11 +921,13 @@ def load(parser, args):
     # the geminicassandra db and files from the VCF
     gemini_loader = GeminiLoader(args)
     gemini_loader.connect_to_db()
+    if not args.no_genotypes and not args.no_load_genotypes:
+        gemini_loader._init_sample_gt_counts()
 
     gemini_loader.populate_from_vcf()
     #gemini_loader.update_gene_table()
-    gemini_loader.disconnect()
     
-    #TODO: nodig?
-    '''if not args.no_genotypes and not args.no_load_genotypes:
-        gemini_loader.store_sample_gt_counts()'''
+    if not args.no_genotypes and not args.no_load_genotypes:
+        gemini_loader.store_sample_gt_counts()
+        
+    gemini_loader.disconnect()
