@@ -11,7 +11,7 @@ T/T	C/C	C/T	C/T
 T/T	T/T	C/C	C/C
 C/T	C/C	C/C	C/C
 ./.	C/C	C/C	./." > exp
-geminicassandra query -q "select (gts).(*)from variants" -ks extended_ped_db --cores 2 > obs
+geminicassandra query -q "select (gts).(*)from variants" -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -30,7 +30,7 @@ chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135210790	135210791	T	C	T/T	T/T	C/C	C/C
 chr10	135336655	135336656	G	A	./.	A/A	./.	A/A
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
-geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*)from variants" --test-mode -ks extended_ped_db --cores 2 > obs
+geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*)from variants" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -48,7 +48,7 @@ chr10	126678091	126678092	G	A	G/G	G/A
 chr10	135210790	135210791	T	C	T/T	T/T
 chr10	135336655	135336656	G	A	./.	A/A
 chr10	135369531	135369532	T	C	T/T	T/T" > exp
-geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" --test-mode -ks extended_ped_db --cores 2 > obs
+geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -60,7 +60,7 @@ echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215
 chr10	135210790	135210791	T	C	T/T	T/T
 chr10	135369531	135369532	T	C	T/T	T/T" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -73,7 +73,7 @@ echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gt_types_m10475	gt_types_m1
 chr10	135210790	135210791	T	C	T/T	T/T	0	0
 chr10	135369531	135369532	T	C	T/T	T/T	0	0" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1'), (gt_types).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -85,7 +85,7 @@ echo "    wildcard_mc.t6...\c"
 echo "chrom	start	end	ref	alt	gts_m10478	gts_m10500
 chr10	135336655	135336656	G	A	A/A	./." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='2') from variants" \
-             --gt-filter "[gt_types].[phenotype=='2'].[!=HOM_REF].[all] && gts.M10478 =='A/A'" -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[phenotype=='2'].[!=HOM_REF].[all] && gts.M10478 =='A/A'" -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -100,7 +100,7 @@ chr10	126678091	126678092	G	A	G/G	G/A
 chr10	135210790	135210791	T	C	T/T	T/T
 chr10	135369531	135369532	T	C	T/T	T/T" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[any]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[any]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -114,7 +114,7 @@ chr10	52004314	52004315	T	C	./.	C/C
 chr10	52497528	52497529	G	C	./.	./.
 chr10	135336655	135336656	G	A	./.	A/A" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[none]" --test-mode -ks  extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[none]" --test-mode -db $cassandra_ips -ks  extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -128,7 +128,7 @@ chr16	72057434	72057435	C	T	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[any]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==HET].[any]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -142,7 +142,7 @@ chr16	72057434	72057435	C	T	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[count>0]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==HET].[count>0]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -154,7 +154,7 @@ echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	48003991	48003992	C	T	T/T	C/C	C/T	C/T
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[count>=2]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==HET].[count>=2]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -169,7 +169,7 @@ chr10	52497528	52497529	G	C	./.	./.	C/C	C/C
 chr10	135210790	135210791	T	C	T/T	T/T	C/C	C/C
 chr10	135336655	135336656	G	A	./.	A/A	./.	A/A" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[count==0]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==HET].[count==0]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -185,7 +185,7 @@ chr16	72057434	72057435	C	T	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2]" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -197,7 +197,7 @@ echo "    wildcard_mc.t14...\c"
 echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2] && gts.M10478 =='G/G'" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2] && gts.M10478 =='G/G'" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -208,7 +208,7 @@ echo "    wildcard_mc.t15...\c"
 echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==    HOM_ALT].[  count   !=2] && gts.M10478 =='G/G'" -ks extended_ped_db --cores 2 > obs
+             --gt-filter "[gt_types].[*].[==    HOM_ALT].[  count   !=2] && gts.M10478 =='G/G'" -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -218,7 +218,7 @@ rm obs exp
 echo "    wildcard_mc.t16...\c"
 echo "Unsupported wildcard operation: (). Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[]" -ks extended_ped_db --cores 2 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[]" -db $cassandra_ips -ks extended_ped_db --cores 2 2> obs
 check obs exp
 rm obs exp
 
@@ -228,7 +228,7 @@ rm obs exp
 echo "    wildcard_mc.t17...\c"
 echo "Unsupported wildcard operation: (amy). Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[amy]" -ks extended_ped_db --cores 2 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[amy]" -db $cassandra_ips -ks extended_ped_db --cores 2 2> obs
 check obs exp
 rm exp
 
@@ -238,7 +238,7 @@ rm exp
 echo "    wildcard_mc.t18...\c"
 echo "Wildcard filter should consist of 4 elements. Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT]" -ks extended_ped_db --cores 2 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT]" -db $cassandra_ips -ks extended_ped_db --cores 2 2> obs
 check obs exp
 rm obs exp
 
@@ -253,7 +253,7 @@ chr10	52004314	52004315	T	C	ASAH2	./.	C/C	C/C	./.
 chr10	52497528	52497529	G	C	ASAH2B	./.	./.	C/C	C/C
 chr10	135336655	135336656	G	A	SPRN	./.	A/A	./.	A/A" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[!=HOM_REF].[count>=1])" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[!=HOM_REF].[count>=1])" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -263,7 +263,7 @@ rm obs exp
 echo "    wildcard_mc.t20...\c"
 echo "No results!" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[all] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" -ks extended_ped_db --cores 2 > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[all] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -275,7 +275,7 @@ echo "chrom	start	end	ref	alt	gene	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr16	72057434	72057435	C	T	DHODH	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	CTBP2	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" --test-mode -ks extended_ped_db --cores 2 > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 2 > obs
 check obs exp
 rm obs exp
 
@@ -293,7 +293,7 @@ T/T	C/C	C/T	C/T
 T/T	T/T	C/C	C/C
 C/T	C/C	C/C	C/C
 ./.	C/C	C/C	./." > exp
-geminicassandra query -q "select (gts).(*)from variants" -ks extended_ped_db --cores 3 > obs
+geminicassandra query -q "select (gts).(*)from variants" -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -312,7 +312,7 @@ chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135210790	135210791	T	C	T/T	T/T	C/C	C/C
 chr10	135336655	135336656	G	A	./.	A/A	./.	A/A
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
-geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*)from variants" --test-mode -ks extended_ped_db --cores 3 > obs
+geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*)from variants" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -330,7 +330,7 @@ chr10	126678091	126678092	G	A	G/G	G/A
 chr10	135210790	135210791	T	C	T/T	T/T
 chr10	135336655	135336656	G	A	./.	A/A
 chr10	135369531	135369532	T	C	T/T	T/T" > exp
-geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" --test-mode -ks extended_ped_db --cores 3 > obs
+geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -342,7 +342,7 @@ echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215
 chr10	135210790	135210791	T	C	T/T	T/T
 chr10	135369531	135369532	T	C	T/T	T/T" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -355,7 +355,7 @@ echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gt_types_m10475	gt_types_m1
 chr10	135210790	135210791	T	C	T/T	T/T	0	0
 chr10	135369531	135369532	T	C	T/T	T/T	0	0" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1'), (gt_types).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[all]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -367,7 +367,7 @@ echo "    wildcard_mc3.t6...\c"
 echo "chrom	start	end	ref	alt	gts_m10478	gts_m10500
 chr10	135336655	135336656	G	A	A/A	./." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='2') from variants" \
-             --gt-filter "[gt_types].[phenotype=='2'].[!=HOM_REF].[all] && gts.M10478 =='A/A'" -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[phenotype=='2'].[!=HOM_REF].[all] && gts.M10478 =='A/A'" -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -382,7 +382,7 @@ chr10	126678091	126678092	G	A	G/G	G/A
 chr10	135210790	135210791	T	C	T/T	T/T
 chr10	135369531	135369532	T	C	T/T	T/T" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[any]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[any]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -396,7 +396,7 @@ chr10	52004314	52004315	T	C	./.	C/C
 chr10	52497528	52497529	G	C	./.	./.
 chr10	135336655	135336656	G	A	./.	A/A" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(phenotype=='1') from variants" \
-             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[none]" --test-mode -ks  extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[phenotype=='1'].[==HOM_REF].[none]" --test-mode -db $cassandra_ips -ks  extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -410,7 +410,7 @@ chr16	72057434	72057435	C	T	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[any]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==HET].[any]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -424,7 +424,7 @@ chr16	72057434	72057435	C	T	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[count>0]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==HET].[count>0]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -436,7 +436,7 @@ echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	48003991	48003992	C	T	T/T	C/C	C/T	C/T
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[count>=2]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==HET].[count>=2]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -451,7 +451,7 @@ chr10	52497528	52497529	G	C	./.	./.	C/C	C/C
 chr10	135210790	135210791	T	C	T/T	T/T	C/C	C/C
 chr10	135336655	135336656	G	A	./.	A/A	./.	A/A" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HET].[count==0]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==HET].[count==0]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -467,7 +467,7 @@ chr16	72057434	72057435	C	T	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G
 chr10	135369531	135369532	T	C	T/T	T/T	T/C	T/C" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2]" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2]" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -479,7 +479,7 @@ echo "    wildcard_mc3.t14...\c"
 echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2] && gts.M10478 =='G/G'" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[count!=2] && gts.M10478 =='G/G'" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -490,7 +490,7 @@ echo "    wildcard_mc3.t15...\c"
 echo "chrom	start	end	ref	alt	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr10	126678091	126678092	G	A	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==    HOM_ALT].[  count   !=2] && gts.M10478 =='G/G'" -ks extended_ped_db --cores 3 > obs
+             --gt-filter "[gt_types].[*].[==    HOM_ALT].[  count   !=2] && gts.M10478 =='G/G'" -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -500,7 +500,7 @@ rm obs exp
 echo "    wildcard_mc3.t16...\c"
 echo "Unsupported wildcard operation: (). Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[]" -ks extended_ped_db --cores 3 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[]" -db $cassandra_ips -ks extended_ped_db --cores 3 2> obs
 check obs exp
 rm obs exp
 
@@ -510,7 +510,7 @@ rm obs exp
 echo "    wildcard_mc3.t17...\c"
 echo "Unsupported wildcard operation: (amy). Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT].[amy]" -ks extended_ped_db --cores 3 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT].[amy]" -db $cassandra_ips -ks extended_ped_db --cores 3 2> obs
 check obs exp
 rm obs exp
 
@@ -520,7 +520,7 @@ rm obs exp
 echo "    wildcard_mc3.t18...\c"
 echo "Wildcard filter should consist of 4 elements. Exiting." > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, (gts).(*) from variants" \
-             --gt-filter "[gt_types].[*].[==HOM_ALT]" -ks extended_ped_db --cores 3 2> obs
+             --gt-filter "[gt_types].[*].[==HOM_ALT]" -db $cassandra_ips -ks extended_ped_db --cores 3 2> obs
 check obs exp
 rm obs exp
 
@@ -535,7 +535,7 @@ chr10	52004314	52004315	T	C	ASAH2	./.	C/C	C/C	./.
 chr10	52497528	52497529	G	C	ASAH2B	./.	./.	C/C	C/C
 chr10	135336655	135336656	G	A	SPRN	./.	A/A	./.	A/A" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[!=HOM_REF].[count>=1])" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[!=HOM_REF].[count>=1])" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -545,7 +545,7 @@ rm obs exp
 echo "    wildcard_mc3.t20...\c"
 echo "No results!" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[all] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" -ks extended_ped_db --cores 3 > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[all] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
@@ -557,7 +557,7 @@ echo "chrom	start	end	ref	alt	gene	gts_m10475	gts_m128215	gts_m10500	gts_m10478
 chr16	72057434	72057435	C	T	DHODH	C/T	C/C	C/C	C/C
 chr10	126678091	126678092	G	A	CTBP2	G/G	G/A	G/G	G/G" > exp
 geminicassandra query --header -q "select chrom, start, end, ref, alt, gene, (gts).(*) from variants" \
-             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" --test-mode -ks extended_ped_db --cores 3 > obs
+             --gt-filter "([gt_types].[phenotype=='1'].[!=HOM_REF].[count>=1] && [gt_types].[phenotype=='2'].[==HOM_REF].[all])" --test-mode -db $cassandra_ips -ks extended_ped_db --cores 3 > obs
 check obs exp
 rm obs exp
 
